[Asterisk-cvs] asterisk/include/asterisk dns.h, 1.1, 1.2 enum.h, 1.3, 1.4

markster at lists.digium.com markster at lists.digium.com
Tue Mar 1 23:19:50 CST 2005


Update of /usr/cvsroot/asterisk/include/asterisk
In directory mongoose.digium.com:/tmp/cvs-serv3036/include/asterisk

Modified Files:
	dns.h enum.h 
Log Message:
Fix ENUM documentation (bug #3698)


Index: dns.h
===================================================================
RCS file: /usr/cvsroot/asterisk/include/asterisk/dns.h,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- dns.h	27 Sep 2003 00:37:07 -0000	1.1
+++ dns.h	2 Mar 2005 05:17:13 -0000	1.2
@@ -14,7 +14,14 @@
 
 struct ast_channel;
 
+/*!	\brief	Perform DNS lookup (used by enum and SRV lookups) 
+	\param	context
+	\param	dname	Domain name to lookup (host, SRV domain, TXT record name)
+	\param	class	Record Class (see "man res_search")
+	\param	type	Record type (see "man res_search")
+	\param	callback Callback function for handling DNS result
+*/
 extern int ast_search_dns(void *context, const char *dname, int class, int type,
-			  int (*callback)(void *context, u_char *answer, int len, u_char *fullanswer));
+	 int (*callback)(void *context, u_char *answer, int len, u_char *fullanswer));
 
 #endif /* _ASTERISK_DNS_H */

Index: enum.h
===================================================================
RCS file: /usr/cvsroot/asterisk/include/asterisk/enum.h,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- enum.h	16 May 2004 18:12:16 -0000	1.3
+++ enum.h	2 Mar 2005 05:17:13 -0000	1.4
@@ -3,19 +3,42 @@
  *
  * ENUM support
  * 
- * Copyright (C) 1999, Mark Spencer
+ * Copyright (C) 1999-2005, Digium, inc
  *
- * Mark Spencer <markster at linux-support.net>
+ * Mark Spencer <markster at digium.com>
  *
  * This program is free software, distributed under the terms of
  * the GNU General Public License
  */
 
+/*!	\file enum.h
+	\brief DNS and ENUM functions
+*/
+
 #ifndef _ASTERISK_ENUM_H
 #define _ASTERISK_ENUM_H
 #include <asterisk/channel.h>
-/* Lookup entry in ENUM Returns 1 if found, 0 if not found, -1 on hangup */
+/*! \brief Lookup entry in ENUM Returns 1 if found, 0 if not found, -1 on hangup 
+	\param chan	Channel
+	\param number	Number in E164 format without the + (for e164.arpa) or format 
+			requested by enum service used (enum.conf)
+	\param location Number returned	(or SIP uri)
+	\param maxloc	Max length
+	\param tech	Technology (from url scheme in response)
+	\param maxtech	Max length
+*/
 extern int ast_get_enum(struct ast_channel *chan, const char *number, char *location, int maxloc, char *technology, int maxtech);
+
+/*!	\brief Lookup DNS TXT record (used by app TXTCIDnum
+	\param chan	Channel
+	\param number	E164 number without the +
+	\param locatio	Number returned	(or SIP uri)
+	\param maxloc	Max length of number
+	\param tech 	Technology (not used in TXT records)
+	\param maxtech	Max length
+	\param txt	Text string (return value)
+	\param maxtxt	Max length of "txt"
+*/
 extern int ast_get_txt(struct ast_channel *chan, const char *number, char *location, int maxloc, char *technology, int maxtech, char *txt, int maxtxt);
 
 extern int ast_enum_init(void);




More information about the svn-commits mailing list